==> haskell-tasty-lua-1.1.1.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-1JdnlJpScmX8mx5nAjnwMe
key:                  tasty-lua-1.1.1.1-1JdnlJpScmX8mx5nAjnwMe
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  e72c96b282424fe46dbf2017da3a73e8
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-1JdnlJpScmX8mx5nAjnwMe
depends:
    QuickCheck-2.15.0.1-4mIWiyi0MCz4O9NEuBQDps base-4.18.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    hslua-core-2.3.2-CDseJJFYF1qIqSY2v4h7A5
    hslua-marshalling-2.3.1-46opmw9wB6bD8oevpHaGjn
    lua-arbitrary-1.0.1.1-HYGZmXthNSe4p9H0bx3lnH
    tasty-1.5.2-QJSnUao0iU3Q0YGBz8WKt

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-lua-1.1.1.1-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-lua
version:              1.1.1.1
visibility:           public
id:                   tasty-lua-1.1.1.1-3CZw2dfvCN9CdAy0hfWVgp
key:                  tasty-lua-1.1.1.1-3CZw2dfvCN9CdAy0hfWVgp
license:              MIT
copyright:            © 2019-2025 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Write tests in Lua, integrate into tasty.
description:          Allow users to define tasty tests from Lua.
category:             Foreign
abi:                  a525c6656a5e0ce74d26601ee64bfd4f
exposed:              True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Arbitrary Test.Tasty.Lua.Core
    Test.Tasty.Lua.Module Test.Tasty.Lua.Translate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-lua-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-lua
hs-libraries:         HStasty-lua-1.1.1.1-3CZw2dfvCN9CdAy0hfWVgp
depends:
    QuickCheck-2.15.0.1-LaRIQHiwv8U7w9VIoXbmQQ base-4.18.2.1
    bytestring-0.11.5.3 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    hslua-core-2.3.2-AavBLrXCtfgGcXsnxoEylh
    hslua-marshalling-2.3.1-AhKJIKvRB6a9bpxUV61P7x
    lua-arbitrary-1.0.1.1-EsAuD1TsUOt4O1x4nF0V4F
    tasty-1.5.2-5ThorlfIy4bAzjwer0MKIq

haddock-interfaces:   /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
